@@ -62,20 +62,10 @@ def Value(find, printEq=False, **kwargs):
     eq = list()
     eq.append("Eq(q,C*v)")    
     eq.append("Eq(C,epsilon*A*d)")
-    eq.append("Eq(v,(1/C)*integrate(i,(t,ti,tf))+v0)")
-    eq.append("Eq(i,C*dv/dt)")
     eq.append("Eq(i,C*diff(v,t))")
     eq.append("Eq(p,v*i)")
     eq.append("Eq(p,C*v*diff(v,t))")
     eq.append("Eq(w,0.5*C*v**2)") 
     eq.append("Eq(w,integrate(C*v,(v,v0,v1)))")
     eq.append("Eq(w,q**2/(2*C))")
-    return solveEqs(eq, find, printEq=printEq, **kwargs)
-
-if __name__ == "__main__":
-    Value(find="v", printEq=True,
-            C=.05,       #Farads
-            i=".004*t",   #A
-            v0=10,        #V
-            ti=0,
-            tf="t")       
\ No newline at end of file
+    return solveEqs(eq, find, printEq=printEq, **kwargs)
\ No newline at end of file
